[master] 6b84197 Spelling cleanup

Andreas Plesner Jacobsen apj at varnish-cache.org
Wed Nov 23 23:48:58 CET 2011


commit 6b84197ee8b0763b43fddea284166298af7e0a73
Author: Andreas Plesner Jacobsen <apj at mutt.dk>
Date:   Wed Nov 23 23:48:45 2011 +0100

    Spelling cleanup

diff --git a/include/vapi/vsl.h b/include/vapi/vsl.h
index dfe5a83..db8b953 100644
--- a/include/vapi/vsl.h
+++ b/include/vapi/vsl.h
@@ -121,7 +121,7 @@ int VSL_Dispatch(struct VSM_data *vd, VSL_handler_f *func, void *priv);
 	 * Return values:
 	 *	!=0:	Non-zero return value from func()
 	 *	0:	no VSL records.
-	 *	-1:	VSL chunk was abandonned.
+	 *	-1:	VSL chunk was abandoned.
 	 *	-2:	End of file (-r) / -k arg exhausted / "done"
 	 */
 
@@ -132,7 +132,7 @@ int VSL_NextSLT(struct VSM_data *lh, uint32_t **pp, uint64_t *bitmap);
 	 * Return values:
 	 *	1:	Valid VSL record at *pp
 	 *	0:	no VSL records
-	 *	-1:	VSL cunkwas abandonned
+	 *	-1:	VSL chunk was abandoned
 	 *	-2:	End of file (-r) / -k arg exhausted / "done"
 	 */
 
diff --git a/include/vapi/vsm_int.h b/include/vapi/vsm_int.h
index b45fdf7..237fabd 100644
--- a/include/vapi/vsm_int.h
+++ b/include/vapi/vsm_int.h
@@ -50,7 +50,7 @@
  *	When manager abandons VSM file, alloc_seq is set to zero, which
  *	never happens in any other circumstances.
  *
- *	If a manager is started and finds and old abandonned VSM segment
+ *	If a manager is started and finds and old abandoned VSM segment
  *	it will zero the alloc_seq in it, before replacing the file.
  *
  * Subscribers will have to monitor two things to make sure they have
diff --git a/lib/libvarnishapi/vsm.c b/lib/libvarnishapi/vsm.c
index 18de315..e11fe26 100644
--- a/lib/libvarnishapi/vsm.c
+++ b/lib/libvarnishapi/vsm.c
@@ -245,7 +245,7 @@ VSM_Close(struct VSM_data *vd)
 /*--------------------------------------------------------------------*/
 
 int
-VSM_Abandonned(const struct VSM_data *vd)
+VSM_Abandoned(const struct VSM_data *vd)
 {
 	struct stat st;
 
@@ -287,7 +287,7 @@ VSM__itern(const struct VSM_data *vd, struct VSM_fantom *vf)
 	AN(vf);
 
 	if (vd->head->alloc_seq == 0)
-		return (0);	/* abandonned VSM */
+		return (0);	/* abandoned VSM */
 	else if (vf->priv != 0) {
 		if (vf->priv != vd->head->alloc_seq)
 			return (0);
@@ -312,7 +312,7 @@ VSM__itern(const struct VSM_data *vd, struct VSM_fantom *vf)
 	vf->e = (char*)vf->b + vf->chunk->len;
 
 	if (vf->priv == 0)
-		return (0);	/* abandonned VSM */
+		return (0);	/* abandoned VSM */
 	if (vf->b == vf->e)
 		return (0);	/* freed chunk */
 	AN(vf->priv);



More information about the varnish-commit mailing list
diff --git a/include/vapi/vsm.h b/include/vapi/vsm.h
index 9635e8f..800cb76 100644
--- a/include/vapi/vsm.h
+++ b/include/vapi/vsm.h
@@ -100,16 +100,16 @@ int VSM_Open(struct VSM_data *vd);
 	 *	<0 on failure, VSM_Error() returns diagnostic string
 	 */
 
-int VSM_Abandonned(const struct VSM_data *vd);
+int VSM_Abandoned(const struct VSM_data *vd);
 	/*
 	 * Find out if the VSM file has been abandonned or closed and should
 	 * be reopened.  This function calls stat(2) and should only be
 	 * used when lack of activity or invalidation of fantoms indicate
 	 * abandonment.
 	 *
 	 * Returns:
 	 *	0  No reopen needed.
-	 *	1  VSM abandonned.
+	 *	1  VSM abandoned.
 	 */
 
 void VSM_Close(struct VSM_data *vd);
@@ -132,7 +132,7 @@ int VSM__itern(const struct VSM_data *vd, struct VSM_fantom *vf);
 int VSM_StillValid(const struct VSM_data *vd, struct VSM_fantom *vf);
 	/*
 	 * This is a cheap syscall-less check to see if the fantom is still
 	 * valid.  Further checking with VSM_Abandonned() may be a good
 	 * idea.
 	 *
 	 * Return:
@@ -100,16 +100,16 @@ int VSM_Open(struct VSM_data *vd);
 	/*
-	 * Find out if the VSM file has been abandonned or closed and should
+	 * Find out if the VSM file has been abandoned or closed and should
 	 * be reopened.  This function calls stat(2) and should only be
 	 * used when lack of activity or invalidation of fantoms indicate
@@ -132,7 +132,7 @@ int VSM__itern(const struct VSM_data *vd, struct VSM_fantom *vf);
 	/*
 	 * This is a cheap syscall-less check to see if the fantom is still
-	 * valid.  Further checking with VSM_Abandonned() may be a good
+	 * valid.  Further checking with VSM_Abandoned() may be a good
 	 * idea.
 	 *